'use strict';

var vue = require('vue');

const useDebouncedCallback = (callback, delay) => {
    const timeout = vue.ref();
    const debouncedFn = (...args) => {
        const handler = () => {
            clearTimeout(timeout.value);
            callback(...args);
        };
        clearTimeout(timeout.value);
        timeout.value = setTimeout(handler, delay);
    };
    return debouncedFn();
};

exports.useDebouncedCallback = useDebouncedCallback;
//# sourceMappingURL=useDebouncedCallback.js.map
