import { PropType } from 'vue';
declare const CDatePicker: import("vue").DefineComponent<{
    /**
     * Default date of the component
     */
    calendarDate: {
        type: (StringConstructor | DateConstructor)[];
    };
    /**
     * Toggle visibility or set the content of cancel button.
     */
    cancelButton: {
        type: (StringConstructor | BooleanConstructor)[];
        default: string;
    };
    /**
     * Sets the color context of the cancel button to one of CoreUI’s themed colors.
     *
     * @values 'primary', 'secondary', 'success', 'danger', 'warning', 'info', 'dark', 'light'
     */
    cancelButtonColor: {
        default: string;
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
     * Size the cancel button small or large.
     *
     * @values 'sm', 'lg'
     */
    cancelButtonSize: {
        type: StringConstructor;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * Set the cancel button variant to an outlined button or a ghost button.
     *
     * @values 'ghost', 'outline'
     */
    cancelButtonVariant: {
        type: StringConstructor;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * Toggle visibility of the cleaner button.
     */
    cleaner: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Toggle visibility or set the content of confirm button.
     */
    confirmButton: {
        type: (StringConstructor | BooleanConstructor)[];
        default: string;
    };
    /**
     * Sets the color context of the confirm button to one of CoreUI’s themed colors.
     *
     * @values 'primary', 'secondary', 'success', 'danger', 'warning', 'info', 'dark', 'light'
     */
    confirmButtonColor: {
        default: string;
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
     * Size the confirm button small or large.
     *
     * @values 'sm', 'lg'
     */
    confirmButtonSize: {
        type: StringConstructor;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * Set the confirm button variant to an outlined button or a ghost button.
     *
     * @values 'ghost', 'outline'
     */
    confirmButtonVariant: {
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
     * Set the format of day name.
     *
     * @default 'numeric'
     * @since 4.6.0
     */
    dayFormat: {
        type: (StringConstructor | FunctionConstructor)[];
        default: string;
        required: false;
        validator: (value: string) => boolean;
    };
    /**
     * Toggle the disabled state for the component.
     */
    disabled: BooleanConstructor;
    /**
     * Specify the list of dates that cannot be selected.
     */
    disabledDates: {
        type: PropType<Date[] | Date[][]>;
    };
    /**
     * Initial selected date.
     */
    date: {
        type: (StringConstructor | DateConstructor)[];
        required: false;
    };
    /**
     * Sets the day of start week.
     * - 0 - Sunday,
     * - 1 - Monday,
     * - 2 - Tuesday,
     * - 3 - Wednesday,
     * - 4 - Thursday,
     * - 5 - Friday,
     * - 6 - Saturday,
     */
    firstDayOfWeek: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * Set date format.
     * We use date-fns to format dates. Visit https://date-fns.org/v2.28.0/docs/format to check accepted patterns.
     */
    format: StringConstructor;
    /**
     * Toggle visibility of footer element or set the content of footer.
     */
    footer: BooleanConstructor;
    /**
     * The id global attribute defines an identifier (ID) that must be unique in the whole document.
     *
     * The name attribute for the input element is generated based on the `id` property:
     * - {id}-date
     */
    id: StringConstructor;
    /**
     * Toggle visibility or set the content of the input indicator.
     */
    indicator: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Toggle the readonly state for the component.
     */
    inputReadOnly: BooleanConstructor;
    /**
     * Custom function to format the selected date into a string according to a custom format.
     *
     * @since v5.0.0-rc.2
     */
    inputDateFormat: FunctionConstructor;
    /**
     * Custom function to parse the input value into a valid Date object.
     *
     * @since v5.0.0-rc.2
     */
    inputDateParse: FunctionConstructor;
    /**
     * Defines the delay (in milliseconds) for the input field's onChange event.
     *
     * @since v5.0.0-rc.2
     */
    inputOnChangeDelay: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * Sets the default locale for components. If not set, it is inherited from the navigator.language.
     */
    locale: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Max selectable date.
     */
    maxDate: {
        type: (StringConstructor | DateConstructor)[];
    };
    /**
     * Min selectable date.
     */
    minDate: {
        type: (StringConstructor | DateConstructor)[];
    };
    /**
     * Show arrows navigation.
     */
    navigation: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Reorder year-month navigation, and render year first.
     *
     * @since 4.6.0
     */
    navYearFirst: BooleanConstructor;
    /**
     * Specifies a short hint that is visible in the input.
     */
    placeholder: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Set whether days in adjacent months shown before or after the current month are selectable. This only applies if the `showAdjacementDays` option is set to true.
     *
     * @since 4.9.0
     */
    selectAdjacementDays: BooleanConstructor;
    /**
     * Specify the type of date selection as day, week, month, or year.
     *
     * @since 5.0.0-rc.2
     */
    selectionType: {
        type: PropType<"day" | "week" | "month" | "year">;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * Set whether to display dates in adjacent months (non-selectable) at the start and end of the current month.
     *
     * @since 4.9.0
     */
    showAdjacementDays: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Set whether to display week numbers in the calendar.
     *
     * @since 5.0.0-rc.2
     */
    showWeekNumber: BooleanConstructor;
    /**
     * Size the component small or large.
     *
     * @values 'sm', 'lg'
     */
    size: {
        type: StringConstructor;
        required: false;
        validator: (value: string) => boolean;
    };
    /**
     * Provide an additional time selection by adding select boxes to choose times.
     */
    timepicker: BooleanConstructor;
    /**
     * Set length or format of day name.
     *
     * @type  number | 'long' | 'narrow' | 'short'
     */
    weekdayFormat: {
        type: (NumberConstructor | StringConstructor | FunctionConstructor)[];
        default: number;
        validator: (value: string | number) => boolean;
    };
    /**
     * Label displayed over week numbers in the calendar.
     *
     * @since 5.0.0-rc.2
     */
    weekNumbersLabel: StringConstructor;
}, () => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
    [key: string]: any;
}>, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, ("date-change" | "update:date")[], "date-change" | "update:date", import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
    /**
     * Default date of the component
     */
    calendarDate: {
        type: (StringConstructor | DateConstructor)[];
    };
    /**
     * Toggle visibility or set the content of cancel button.
     */
    cancelButton: {
        type: (StringConstructor | BooleanConstructor)[];
        default: string;
    };
    /**
     * Sets the color context of the cancel button to one of CoreUI’s themed colors.
     *
     * @values 'primary', 'secondary', 'success', 'danger', 'warning', 'info', 'dark', 'light'
     */
    cancelButtonColor: {
        default: string;
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
     * Size the cancel button small or large.
     *
     * @values 'sm', 'lg'
     */
    cancelButtonSize: {
        type: StringConstructor;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * Set the cancel button variant to an outlined button or a ghost button.
     *
     * @values 'ghost', 'outline'
     */
    cancelButtonVariant: {
        type: StringConstructor;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * Toggle visibility of the cleaner button.
     */
    cleaner: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Toggle visibility or set the content of confirm button.
     */
    confirmButton: {
        type: (StringConstructor | BooleanConstructor)[];
        default: string;
    };
    /**
     * Sets the color context of the confirm button to one of CoreUI’s themed colors.
     *
     * @values 'primary', 'secondary', 'success', 'danger', 'warning', 'info', 'dark', 'light'
     */
    confirmButtonColor: {
        default: string;
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
     * Size the confirm button small or large.
     *
     * @values 'sm', 'lg'
     */
    confirmButtonSize: {
        type: StringConstructor;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * Set the confirm button variant to an outlined button or a ghost button.
     *
     * @values 'ghost', 'outline'
     */
    confirmButtonVariant: {
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
     * Set the format of day name.
     *
     * @default 'numeric'
     * @since 4.6.0
     */
    dayFormat: {
        type: (StringConstructor | FunctionConstructor)[];
        default: string;
        required: false;
        validator: (value: string) => boolean;
    };
    /**
     * Toggle the disabled state for the component.
     */
    disabled: BooleanConstructor;
    /**
     * Specify the list of dates that cannot be selected.
     */
    disabledDates: {
        type: PropType<Date[] | Date[][]>;
    };
    /**
     * Initial selected date.
     */
    date: {
        type: (StringConstructor | DateConstructor)[];
        required: false;
    };
    /**
     * Sets the day of start week.
     * - 0 - Sunday,
     * - 1 - Monday,
     * - 2 - Tuesday,
     * - 3 - Wednesday,
     * - 4 - Thursday,
     * - 5 - Friday,
     * - 6 - Saturday,
     */
    firstDayOfWeek: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * Set date format.
     * We use date-fns to format dates. Visit https://date-fns.org/v2.28.0/docs/format to check accepted patterns.
     */
    format: StringConstructor;
    /**
     * Toggle visibility of footer element or set the content of footer.
     */
    footer: BooleanConstructor;
    /**
     * The id global attribute defines an identifier (ID) that must be unique in the whole document.
     *
     * The name attribute for the input element is generated based on the `id` property:
     * - {id}-date
     */
    id: StringConstructor;
    /**
     * Toggle visibility or set the content of the input indicator.
     */
    indicator: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Toggle the readonly state for the component.
     */
    inputReadOnly: BooleanConstructor;
    /**
     * Custom function to format the selected date into a string according to a custom format.
     *
     * @since v5.0.0-rc.2
     */
    inputDateFormat: FunctionConstructor;
    /**
     * Custom function to parse the input value into a valid Date object.
     *
     * @since v5.0.0-rc.2
     */
    inputDateParse: FunctionConstructor;
    /**
     * Defines the delay (in milliseconds) for the input field's onChange event.
     *
     * @since v5.0.0-rc.2
     */
    inputOnChangeDelay: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * Sets the default locale for components. If not set, it is inherited from the navigator.language.
     */
    locale: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Max selectable date.
     */
    maxDate: {
        type: (StringConstructor | DateConstructor)[];
    };
    /**
     * Min selectable date.
     */
    minDate: {
        type: (StringConstructor | DateConstructor)[];
    };
    /**
     * Show arrows navigation.
     */
    navigation: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Reorder year-month navigation, and render year first.
     *
     * @since 4.6.0
     */
    navYearFirst: BooleanConstructor;
    /**
     * Specifies a short hint that is visible in the input.
     */
    placeholder: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Set whether days in adjacent months shown before or after the current month are selectable. This only applies if the `showAdjacementDays` option is set to true.
     *
     * @since 4.9.0
     */
    selectAdjacementDays: BooleanConstructor;
    /**
     * Specify the type of date selection as day, week, month, or year.
     *
     * @since 5.0.0-rc.2
     */
    selectionType: {
        type: PropType<"day" | "week" | "month" | "year">;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * Set whether to display dates in adjacent months (non-selectable) at the start and end of the current month.
     *
     * @since 4.9.0
     */
    showAdjacementDays: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Set whether to display week numbers in the calendar.
     *
     * @since 5.0.0-rc.2
     */
    showWeekNumber: BooleanConstructor;
    /**
     * Size the component small or large.
     *
     * @values 'sm', 'lg'
     */
    size: {
        type: StringConstructor;
        required: false;
        validator: (value: string) => boolean;
    };
    /**
     * Provide an additional time selection by adding select boxes to choose times.
     */
    timepicker: BooleanConstructor;
    /**
     * Set length or format of day name.
     *
     * @type  number | 'long' | 'narrow' | 'short'
     */
    weekdayFormat: {
        type: (NumberConstructor | StringConstructor | FunctionConstructor)[];
        default: number;
        validator: (value: string | number) => boolean;
    };
    /**
     * Label displayed over week numbers in the calendar.
     *
     * @since 5.0.0-rc.2
     */
    weekNumbersLabel: StringConstructor;
}>> & {
    "onDate-change"?: ((...args: any[]) => any) | undefined;
    "onUpdate:date"?: ((...args: any[]) => any) | undefined;
}, {
    footer: boolean;
    disabled: boolean;
    dayFormat: string | Function;
    firstDayOfWeek: number;
    locale: string;
    navigation: boolean;
    navYearFirst: boolean;
    selectAdjacementDays: boolean;
    selectionType: "day" | "week" | "month" | "year";
    showAdjacementDays: boolean;
    showWeekNumber: boolean;
    weekdayFormat: string | number | Function;
    cancelButton: string | boolean;
    cancelButtonColor: string;
    cancelButtonSize: string;
    cancelButtonVariant: string;
    cleaner: boolean;
    confirmButton: string | boolean;
    confirmButtonColor: string;
    confirmButtonSize: string;
    indicator: boolean;
    inputOnChangeDelay: number;
    inputReadOnly: boolean;
    placeholder: string;
    timepicker: boolean;
}, {}>;
export { CDatePicker };
